
# Slot: permissible_values


A list of possible values for a slot range

URI: [linkml:permissible_values](https://w3id.org/linkml/permissible_values)


## Domain and Range

[EnumDefinition](EnumDefinition.md) &#8594;  <sub>0..\*</sub> [PermissibleValue](PermissibleValue.md)

## Parents


## Children


## Used by

 * [EnumDefinition](EnumDefinition.md)
